@@ -1,8 +1,28 @@
 import random
-
+import os
 def rand(rnd1,rnd2):
   random.randint(rnd1, rnd2)
-  
+
+def curdir():
+  return os.getcwd()
+
+def get_file_path(file_name):
+  return os.path.join(curdir(), file_name)
+
+def get_file_name(file_path):
+  return os.path.basename(file_path)
+
+def get_file_extension(file_name):
+  return os.path.splitext(file_name)[1]
+
+def get_file_size(file_path):
+  return os.path.getsize(file_path)
+
+def get_file_date(file_path):
+  return os.path.getmtime
+
+def openf(filename):
+  os.system(filename)
 
 def slist(inp,revers):
   if type(inp) is list:
